@@ -12,6 +12,9 @@ those steps:\n
 Steps 2 to 4 are an 'iteration' of the learning and are repeated until either the user stops the algorithm or some
 threshold is reached. In IFRA, no thresholds exist, and the learning stops when the user(s) decide so.
 
+Differential privacy is automatically applied in each node by slightly changing the prediction of the rules.
+(Only working for regression rule for now)
+
 IFRA consists of 3 independent and asynchronous actors, represented by the abstract class `ifra.actor.Actor`.
 Each can be run individually and monitors changes in its inputs. The three actors are :
   * Nodes (**inputs**: data, central model, **output**: node model) (`ifra.node.Node`)
@@ -27,7 +30,8 @@ the aggregator does not have access to any information about the node. It does n
 
 In IFRA, one node produces one ruleset using the `ruleskit` package. Each user is free to define its own model by
 overloading the `ifra.fitters.Fitter` class. The available models currently are:\n
-  * decisiontree (see `ifra.fitters.DecisionTreeFitter` for details)\n
+  * decisiontreeregression (see `ifra.fitters.DecisionTreeRegressionFitter` for details)\n
+  * decisiontreeclassification (see `ifra.fitters.DecisionTreeClassificationFitter` for details)\n
 The user also has the liberty to define its own aggregation method, by overloading `ifra.aggregation.Aggregation`.
 The available aggregation methods currently are:\n
   * adaboost (see `ifra.aggregations.AdaBoostAggregation` for details)\n
@@ -38,7 +42,7 @@ Each node has the possbility to execute a dataprep before the first learning. Th
 dataprep method by overloading the `ifra.datapreps.DataPrep` class. The available datapreps currently are:\n
   * binfeatures (see `ifra.datapreps.BinFeaturesDataPrep`)\n
 
-To overlead a class, read its documentation. Then, to make the actors use your class specify them in the
+To overload a class, read its documentation. Then, to make the actors use your class specify them in the
 actor's configuration file (`ifra.config.NodeLearningConfig` for *fitter*, *node updater* and *dataprep*) or in
 `ifra.config.AggregatorConfig` json file for *aggregation*).
 To be correctly imported, the line passed in the json for, let's say, the aggregation, must be like
@@ -91,7 +95,6 @@ Example of step 1: you could create nodes learning configuration json files cont
 >>>     "x_mins": "",
 >>>     "x_maxs": "",
 >>>     "max_depth": 3,
->>>     "remember_activation": false,
 >>>     "stack_activation": false,
 >>>     "plot_data": true,
 >>>     "get_leaf": false,
@@ -184,15 +187,6 @@ from .node_model_updaters import NodeModelUpdater
 from .fitters import Fitter
 from .aggregations import Aggregation
 from .setup_logger import setup_logger
-from .predictor import (
-    Predictor,
-    RegressionPredictor,
-    ClassificationPredictor,
-    EquallyWeightedClassificator,
-    EquallyWeightedRegressor,
-    CriterionWeightedRegressor,
-    CriterionWeightedClassificator,
-)
 from .configs import AggregatorConfig, CentralConfig, NodeLearningConfig, NodeDataConfig
 
 try:
